ImgCard class

A card that displays an image Caches the image with CachedNetworkImage imgUrl is the url of the image description optional description of the image isFavorite function which checks whether a imgUrl is a favorite toggleFavorite function which toggles the favorite status of a imgUrl

Inheritance

Constructors

ImgCard({required String imgUrl, String? description, bool isFavorite(String)?, void toggleFavorite(String)?, Key? key})
const

Properties

description → String?
The description of the image
final
hashCode → int
The hash code for this object.
no setterinherited
imgUrl → String
The url of the image
final
isFavorite → bool Function(String)?
Function which toggles the favorite status of a imgUrl
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toggleFavorite → void Function(String)?
Function which checks whether a imgUrl is a favorite
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
share(BuildContext context) → Future<void>
Share image with share_plus
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited